@@ -31,11 +31,12 @@ case "$1" in
     ;;
 esac
 
-
-chown benno.benno /var/log/benno
-chown benno.benno /srv/benno/archive
-chown benno.benno /srv/benno/inbox
-chmod 2770 /srv/benno/inbox
+set +e
+chown --silent benno.benno /var/log/benno
+chown --silent benno.benno /srv/benno/archive
+chown --silent benno.benno /srv/benno/inbox
+chmod --silent 2770 /srv/benno/inbox
+set -e
 
 if [ -x "/etc/init.d/benno-archive" ]; then
 	update-rc.d benno-archive defaults >/dev/null
